@@ -10,6 +10,7 @@ use strictures 2;
 use namespace::clean;
 
 use OpenAI::API::Config;
+use OpenAI::API::Error;
 
 has 'config' => (
     is      => 'ro',
@@ -50,14 +51,22 @@ sub request_params {
 sub send {
     my $self = shift;
 
-    if (@_) {
+    if ( @_ == 1 ) {
         warn "Sending config via send is deprecated. More info: perldoc OpenAI::API::Config\n";
     }
 
-    return
+    my %args = @_;
+
+    my $res =
           $self->method eq 'POST' ? $self->_post()
         : $self->method eq 'GET'  ? $self->_get()
         :                           die "Invalid method";
+
+    if ( $args{http_response} ) {
+        return $res;
+    }
+
+    return decode_json( $res->decoded_content );
 }
 
 sub _get {
@@ -75,12 +84,26 @@ sub _post {
 }
 
 sub send_async {
-    my ($self) = @_;
+    my ( $self, %args ) = @_;
 
-    return
+    my $res_promise =
           $self->method eq 'POST' ? $self->_post_async()
         : $self->method eq 'GET'  ? $self->_get_async()
         :                           die "Invalid method";
+
+    if ( $args{http_response} ) {
+        return $res_promise;
+    }
+
+    # Return a new promise that resolves to $res->decoded_content
+    my $decoded_content_promise = $res_promise->then(
+        sub {
+            my $res = shift;
+            return decode_json( $res->decoded_content );
+        }
+    );
+
+    return $decoded_content_promise;
 }
 
 sub _get_async {
@@ -136,10 +159,14 @@ sub _send_request {
     my $res = $cond_var->recv();
 
     if ( !$res->is_success ) {
-        die "Error: '@{[ $res->status_line ]}'";
+        OpenAI::API::Error->throw(
+            message  => "Error: '@{[ $res->status_line ]}'",
+            request  => $req,
+            response => $res,
+        );
     }
 
-    return decode_json( $res->decoded_content );
+    return $res;
 }
 
 sub _send_request_async {
@@ -150,10 +177,14 @@ sub _send_request_async {
             my $res = shift;
 
             if ( !$res->is_success ) {
-                die "Error: '@{[ $res->status_line ]}'";
+                OpenAI::API::Error->throw(
+                    message  => "Error: '@{[ $res->status_line ]}'",
+                    request  => $req,
+                    response => $res,
+                );
             }
 
-            return decode_json( $res->decoded_content );
+            return $res;
         }
     )->catch(
         sub {
